function [nladct,nlind,cs]=NLA_DCT(f,tol) 
%
%NLA_DCT returns the nonlinear approximation of a 1D signal by fast dct
%
%Usage:   [nladct,nlind,c0,cc]=NLA_DCT(f,tol);
%
% Inputs:
%   f       analyzing signal
%   tol     desired tolerance to the approximation error 
%   
% Outputs:
%   nladct approximate signal
%   nlind indices of the nonzero coeficients
%   cc sparse coeffients.
%
c=dct(f); %transfort with dct to get coeffients
cc=zeros(size(c));
[cs,ic]=sort(abs(c)); %sorts coefficients (smalest to largest abs values) 
nerror=cumsum(cs.^2); %error norm as a function of number of coefficients
nlind=ic(nerror>=tol^2); %selects the indices of largest coefficients up to error tol
cs=c(nlind);
cc(nlind)=cs;% sparse coefficients vector 
nladct=idct(cc);%invert dct to get the approximation
%final_error=norm(nladct-f);
%
%============================================
%Laura Rebollo-Neira
%Maths Deparment- Aston Uni- UK (July 2011)
%============================================
%
